@@ -60,22 +60,33 @@ def main():
         action="store_true",
         help="only display generated changelog without actually doing the release",
     )
+    parser.add_argument(
+        "-d",
+        "--dry-run",
+        action="store_true",
+        help="simulate a full run of release-new while not committing",
+    )
 
     args = parser.parse_args()
 
     if args.preview_changelog:
-        print(generate_changelog("upcoming release").strip())
+        if Path("doc/changes/changelog.rst").exists():
+            changelog_format = "rst"
+        else:
+            changelog_format = "md"
+
+        print(generate_changelog("upcoming release", format=changelog_format).strip())
         return
 
     try:
-        do_release(args.release_type, args.no_previous_tag_check)
+        do_release(args.release_type, args.no_previous_tag_check, dry_run=args.dry_run)
     except RepositoryNotReadForReleaseError as exception:
         # kdo Arthur
         print(f"⚠️ Error: {exception} 🤯🙉🙈💥")
         sys.exit(1)
 
 
-def do_release(release_type, no_previous_tag_check):
+def do_release(release_type, no_previous_tag_check, dry_run):
     if release_type == "auto":
         effective_release_type = _compute_release_tags()
     else:
@@ -226,8 +237,32 @@ def do_release(release_type, no_previous_tag_check):
             return
 
     changelog_path = Path("CHANGELOG.md")
+    changelog_format = "md"
     if changelog_path.exists():
         previous_content = changelog_path.read_text()
+    elif Path("doc/changes/changelog.rst").exists():
+        # we are in CubicWeb
+        minor_version = f"{assignement.value[0].value}.{assignement.value[1].value}"
+        changelog_path = Path(f"doc/changes/{minor_version}.rst")
+        changelog_format = "rst"
+        previous_content = ""
+
+        if changelog_path.exists():
+            with open(changelog_path, "r") as f:
+                previous_content = f.read()
+
+        with open("doc/changes/changelog.rst", "r") as f:
+            changelog_rst = f.read()
+
+        if f".. include:: {minor_version}.rst" not in changelog_rst:
+            title, includes = changelog_rst.split("\n\n", 1)
+
+            with open("doc/changes/changelog.rst", "w") as f:
+                f.write(title)
+                f.write("\n\n")
+                f.write(f".. include:: {minor_version}.rst\n")
+                f.write(includes)
+
     else:
         print("You don't have any CHANGELOG, let's create one")
         print("and let's add it to your MANIFEST.in if necessary.")
@@ -241,7 +276,9 @@ def do_release(release_type, no_previous_tag_check):
                 )
 
     changelog_content = (
-        generate_changelog(new_version).rstrip() + "\n\n" + previous_content.lstrip()
+        generate_changelog(new_version, format=changelog_format).rstrip()
+        + "\n\n"
+        + previous_content.lstrip()
     ).strip()
 
     changelog_path.write_text(changelog_content)
@@ -258,19 +295,25 @@ def do_release(release_type, no_previous_tag_check):
             shell=True,
         )
 
-    subprocess.check_call(
-        f'hg commit -m "chore(pkg): new {effective_release_type} release ({new_version})"',
-        shell=True,
-    )
+    if not dry_run:
+        subprocess.check_call(
+            f'hg commit -m "chore(pkg): new {effective_release_type} release ({new_version})"',
+            shell=True,
+        )
 
-    subprocess.check_call(f'hg tag "{new_version}"', shell=True)
-    subprocess.check_call("hg phase -p .", shell=True)
+        subprocess.check_call(f'hg tag "{new_version}"', shell=True)
+        subprocess.check_call("hg phase -p .", shell=True)
 
-    # emojis for Arthur
-    print(
-        f"🎉 Congratulation, we've made a new {effective_release_type} release {new_version} \\o/ 🎇"
-    )
-    print()
-    print("✨ 🍰 ✨")
-    print()
-    print("Now you need to hg push the new commits")
+        # emojis for Arthur
+        print(
+            f"🎉 Congratulation, we've made a new {effective_release_type} release {new_version} "
+            "\\o/ 🎇"
+        )
+        print()
+        print("✨ 🍰 ✨")
+        print()
+        print("Now you need to hg push the new commits")
+
+    else:
+        subprocess.check_call("hg status", shell=True)
+        subprocess.check_call("hg diff", shell=True)
